@@ -1,12 +1,13 @@
 package Bio::Graphics::Browser2::UserTracks;
 
-# $Id: UserTracks.pm 22339 2009-12-08 19:04:34Z lstein $
+# $Id: UserTracks.pm 22409 2009-12-15 15:54:35Z lstein $
 use strict;
 use Bio::Graphics::Browser2::DataSource;
 use Bio::Graphics::Browser2::DataLoader;
 use File::Spec;
 use File::Basename 'basename';
 use File::Path 'mkpath','rmtree';
+use IO::File;
 use IO::String;
 use Carp 'croak';
 
@@ -46,11 +47,11 @@ sub language { shift->{language}  }
 
 sub path {
     my $self   = shift;
-    $self->config->userdata($self->state->{uploadid});
+    $self->config->userdata($self->state->{uploadid}||'');
 }
 
 sub tracks {
-    my $self = shift;
+    my $self     = shift;
     my $path     = $self->path;
     my $imported = shift;
 
@@ -59,9 +60,6 @@ sub tracks {
     while (my $dir = readdir(D)) {
 	next if $dir =~ /^\.+$/;
 
-	# my $is_busy       = (-e File::Spec->catfile($path,$dir,$self->busy_file_name))||0;
-	# next if $is_busy;
-
 	my $is_imported   = (-e File::Spec->catfile($path,$dir,$self->imported_file_name))||0;
 	next if defined $imported && $imported != $is_imported;
 
@@ -205,6 +203,7 @@ sub import_url {
     my $conf = $self->track_conf($track_name);
     open my $f,">",$conf or croak "Couldn't open $conf: $!";
     print $f <<END;
+>>>>>>>>>>>>>> cut here <<<<<<<<<<<<
 [$track_name]
 remote feature = $url
 category = My Tracks:Remote Tracks
@@ -220,19 +219,27 @@ END
 
 sub upload_data {
     my $self = shift;
-    my ($file_name,$data,$overwrite) = @_;
+    my ($file_name,$data,$content_type,$overwrite) = @_;
     my $io = IO::String->new($data);
-    $self->upload_file($file_name,$io,$overwrite);
+    $self->upload_file($file_name,$io,$content_type,$overwrite);
 }
 
 sub upload_file {
     my $self = shift;
-    my ($file_name,$fh,$overwrite) = @_;
+    my ($file_name,$fh,$content_type,$overwrite) = @_;
     
     my $track_name = $self->trackname_from_url($file_name,!$overwrite);
+    $content_type ||= '';
+
+    if ($content_type eq 'application/gzip' or $file_name =~ /\.gz$/) {
+	$fh = $self->install_filter($fh,'gunzip -c');
+    } elsif ($content_type eq 'application/bzip2' or $file_name =~ /\.bz2$/) {
+	$fh = $self->install_filter($fh,'bunzip2 -c');
+    }
 
     # guess the file type from the first non-blank line
-    my ($type,$lines)   = $self->guess_upload_type($fh);
+    my ($type,$lines)   = $self->guess_upload_type($file_name,$fh);
+    $lines            ||= [];
     my (@tracks,$fcgi);
 
     my $result= eval {
@@ -257,6 +264,7 @@ sub upload_file {
     }
 
     my $msg = $@;
+    warn $msg if $msg;
     $self->delete_file($track_name) unless $result;
     return ($result,"$msg",\@tracks);
 }
@@ -299,7 +307,7 @@ sub merge_conf {
     # read the rest
     while (<$fh>) {
 	if (/^\[/) {
-	    (my $stanza = $_) =~ s/\[(\w+?)_.+_(\d+)\]\s*\n/$1_$2/;
+	    (my $stanza = $_) =~ s/\[(\w+?)_.+_(\d+)(:\d+)?\]\s*\n/$1_$2$3/;
 	    if (my $body = $stanzas{$stanza}) {
 		$merged .= $_;
 		$merged .= "database = $database\n";
@@ -344,7 +352,16 @@ sub get_loader {
 
 sub guess_upload_type {
     my $self = shift;
-    my $fh   = shift;
+    my ($filename,$fh) = @_;
+
+    # first guess based on file names
+    return ('gff')          if $filename =~ /\.gff(\.(gz|bz2|Z))?$/i;
+    return ('gff3')         if $filename =~ /\.gff3(\.(gz|bz2|Z))?$/i;
+    return ('bed')          if $filename =~ /\.bed(\.(gz|bz2|Z))?$/i;
+    return ('wiggle')       if $filename =~ /\.wig(\.(gz|bz2|Z))?$/i;
+    return ('featurefile')  if $filename =~ /\.fff(\.(gz|bz2|Z))?$/i;
+    return ('bam')          if $filename =~ /\.bam(\.gz)?$/i;
+    return ('sam')          if $filename =~ /\.sam(\.gz)?$/i;
 
     my @lines;
     while (my $line = <$fh>) {
@@ -357,12 +374,33 @@ sub guess_upload_type {
 	return ('bed',\@lines)         if $line =~ /^\w+\s+\d+\s+\d+/;
 	return ('sam',\@lines)         if $line =~ /^\@[A-Z]{2}/;
 	return ('sam',\@lines)         if $line =~ /^[^ \t\n\r]+\t[0-9]+\t[^ \t\n\r@=]+\t[0-9]+\t[0-9]+\t(?:[0-9]+[MIDNSHP])+|\*/;
-	return ('bam',\@lines)         if $line =~ /^BAM\001/;
+	return ('bam',\@lines)         if substr($line,0,6) eq "\x1f\x8b\x08\x04\x00\x00";
     }
 
     return;
 }
 
+sub install_filter {
+    my $self = shift;
+    my ($in_fh,$command) = @_;
+
+    my $child = open(my $out_fh,"-|");
+    defined $child or die "Couldn't fork for pipe: $!";
+    return $out_fh if $child;
+
+    # we are in child now
+    my $unzip = IO::File->new("| $command") or die "Can't open $command: $!";
+    my $buffer;
+    while ((my $bytes = read($in_fh,$buffer,8192))>0) {
+	$unzip->print($buffer);
+    }
+    close $unzip;
+    exit 0;
+}
+
+
+
+
 package Bio::Graphics::Browser2::UserConf;
 
 use base 'Tie::Handle';
@@ -396,7 +434,7 @@ sub READLINE {
 	}
 	next unless $self->{seen_cut};
 	next if $line =~ /^\s*database/;
-	$line =~ s/\[(\w+?)_.+_(\d+)\]/[$1_$2]/;
+	$line =~ s/\[(\w+?)_.+_(\d+)(:\d+)?\]/[$1_$2$3]/;
 	return $line;
     }
     return;
@@ -404,5 +442,4 @@ sub READLINE {
 
 sub CLOSE { close shift->{fh} } 
 
-
 1;
